==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "顧客"

, "State"
: "ステート"

, "Role"
: ""

, "Source"
: "ソース"

, "Start"
: "開始"

, "Scheduled end"
: "計画終了"

, "End"
: "終了"

, "Turnover"
: "取引高"

, "Probability"
: "確度"

, "Folder"
: "フォルダー"

, "Updated by"
: "更新者"

, "Updated Fields:"
: "更新フィールド："

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: ""

, "Lead %s has been changed"
: "リード%s は変更されました"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: "リードデータ"

, "Leadstate"
: "リードスタイル"

, "Leadtype"
: "リードタイプ"

, "Leadsource"
: "リードソース"

, "End Scheduled"
: "スケジュールされた終了"

, "Contacts"
: "コンタクト"

, "Address"
: "住所"

, "Telephone"
: "電話番号"

, "Email"
: "Eメール"

, "Tasks"
: "タスク"

, "Due Date"
: "期日"

, "Priority"
: "重要度"

, "Products"
: "プロダクト"

, "low"
: "低"

, "normal"
: "波"

, "high"
: "高"

, "urgent"
: "緊急"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Lead, Leads"
: [
  ""

]
, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: "リード名"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Estimated end"
: "終了予定"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "パートナ"

, "Phone"
: "電話"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "ステータス"

, "Change type to Customer"
: "顧客タイプの変更"

, "Responsible"
: "責任"

, "Change type to Responsible"
: "責任者の変更"

, "Change type to Partner"
: "パートナタイプの変更"

, "Change contact type"
: "コンタクトタイプの編集"

, "Search for Contacts to add ..."
: "コンタクトの検索と追加"

, "Name"
: "名前"

, "Data"
: ""

, "Cellphone"
: "携帯電話"

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "No Tasks to display"
: "表示するタスクがありません"

, "Summary"
: "要約"

, "Add a task..."
: "タスクを追加しています..."

, "Percent"
: "パーセント"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "概算売上見積"

, "Description"
: "説明"

, "Enter description"
: "説明を入力してください"

, "New Lead"
: ""

, "Product"
: ""

, "Price"
: "価格"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "オープン"

, "contacted"
: "コンタクト済"

, "waiting for feedback"
: "フィードバック待ち"

, "quote sent"
: "見積送付済"

, "accepted"
: "受注"

, "lost"
: "失注"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: ""

, "Lead name"
: "リード名"

, "Responsible"
: "責任"

, "Partner"
: "パートナ"

, "Customer"
: "顧客"

, "Leadstate"
: "リードスタイル"

, "Leadtype"
: "リードタイプ"

, "Leadsource"
: "リードソース"

, "Probability"
: "確度"

, "Turnover"
: "取引高"

, "Estimated end"
: "終了予定"

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Tasks"
: "タスク"

, "No Tasks to display"
: "表示するタスクがありません"

, "Summary"
: "要約"

, "Add a task..."
: "タスクを追加しています..."

, "Due Date"
: "期日"

, "Priority"
: "重要度"

, "Percent"
: "パーセント"

, "Status"
: "ステータス"

, "Organizer"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""

]
, "Select Lead"
: ""

, "Role"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "電話"

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "開始"

, "Change type to Customer"
: "顧客タイプの変更"

, "Change type to Responsible"
: "責任者の変更"

, "Change type to Partner"
: "パートナタイプの変更"

, "Change contact type"
: "コンタクトタイプの編集"

, "Search for Contacts to add ..."
: "コンタクトの検索と追加"

, "Name"
: "名前"

, "Address"
: "住所"

, "Data"
: ""

, "Cellphone"
: "携帯電話"

, "End"
: "終了"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "プロダクト"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: "概算売上見積"

, "Description"
: "説明"

, "Enter description"
: "説明を入力してください"

, "lead list, lead lists"
: [
  ""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: ""

, "Price"
: "価格"

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "オープン"

, "contacted"
: "コンタクト済"

, "waiting for feedback"
: "フィードバック待ち"

, "quote sent"
: "見積送付済"

, "accepted"
: "受注"

, "lost"
: "失注"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "ステート"

, "Source"
: "ソース"

, "Scheduled end"
: "計画終了"

, "Folder"
: "フォルダー"

, "Updated by"
: "更新者"

, "Updated Fields:"
: "更新フィールド："

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "リード%s は変更されました"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: "リードデータ"

, "End Scheduled"
: "スケジュールされた終了"

, "Contacts"
: "コンタクト"

, "Telephone"
: "電話番号"

, "Email"
: "Eメール"

, "low"
: "低"

, "normal"
: "波"

, "high"
: "高"

, "urgent"
: "緊急"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
